@@ -132,7 +132,12 @@ PYBIND11_MODULE(HX711, m) {
         .def("__float__",
             static_cast<double (Mass::*)() const>(&Mass::operator double))
 
-        .def("getValue", &Mass::getValue)
+        .def("getValue",
+            static_cast<double(Mass::*)() const>(&Mass::getValue))
+
+        .def("getValue",
+            static_cast<double(Mass::*)(const Mass::Unit) const>(&Mass::getValue),
+            "u"_a)
 
         .def("getUnit", &Mass::getUnit)
         .def("setUnit", &Mass::setUnit, "u"_a)
@@ -222,6 +227,11 @@ PYBIND11_MODULE(HX711, m) {
         .def(py::init<const int, const int, const Rate>(),
             "dataPin"_a, "clockPin"_a, "rate"_a = Rate::HZ_10)
 
+        .def("__enter__", [](const py::object& hx) { return hx; })
+
+        .def("__exit__", [](py::object& obj, py::args args) { 
+            obj.cast<HX711::HX711*>()->close(); })
+
         .def("begin", &HX711::HX711::begin)
 
         .def("setStrictTiming", &HX711::HX711::setStrictTiming, "strict"_a)
